==> HostCMS.Free_6.7.tar.gz: modules/informationsystem/group/i18n/en.php <==
<?php
/**
 * Information systems.
 *
 * @package HostCMS
 * @subpackage Informationsystem
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Information groups',
	'information_system_top_menu_groups' => 'Information group',
	'show_information_groups_link1' => 'Add',
	'show_information_groups_link4' => 'Properties',
	'information_groups_add_form_title' => 'Add information group',
	'information_groups_edit_form_title' => 'Edit information group',
	'tab_1' => 'Description',
	'tab_2' => 'SEO',
	'tab_3' => 'Additional properties',

	'id' => 'Id',
	'informationsystem_id' => 'Informationsystem id',
	'name' => '<acronym title="Name of information group">Name of information group</acronym>',
	'description' => '<acronym title="Description of information group">Description of information group</acronym>',
	'exec_typograph_description' => '<acronym title="Use prepress service to description of information group">Use prepress service</acronym>',
	'use_trailing_punctuation' => '<acronym title="Optical text alignment function moves punctuation characters beyond the typing borders">Optical alignment</acronym>',
	'parent_id' => '<acronym title="Parent group of information group">Parent group</acronym>',
	'sorting' => '<acronym title="Sorting order of information group">Sorting order</acronym>',
	'path' => '<acronym title="URL item of information system for group">Path</acronym>',
	'indexing' => '<acronym title="Checkbox to specify whether information group should be indexed">Index</acronym>',
	'active' => '<acronym title="Activity status of information group">Active</acronym>',
	'siteuser_id' => '<acronym title="Website user ID that information group belongs to">User code</acronym>',
	'siteuser_group_id' => '<acronym title="Group having access rights to information group">Access group</acronym>',
	'information_parent' => 'Like parent',

	'image_large' => '<acronym title="Picture of information group">Picture</acronym>',
	'image_small' => '<acronym title="Small picture of information group">Small picture</acronym>',

	'seo_title' => '<acronym title="Meta element title">Title</acronym>',
	'seo_description' => '<acronym title="Meta element description">Description</acronym>',
	'seo_keywords' => '<acronym title="Meta element keywords">Keywords</acronym>',

	'edit_success' => 'Information system added successfully.',
	//'edit_information_groups_success' => "Information system saved successfully!",

	'edit_error' => 'Information group has not been added!',
	//'edit_information_groups_error' => "Error! Information group has not been modified!",

	'markDeleted_success' => 'Information group deleted successfully.',
	//'delete_information_groups_success' => "Information groups deleted successfully!",

	'markDeleted_error' => 'Information group has not been deleted!',

	'error_URL_information_group' => 'Group already contains information subgroup with this URL!',
	'error_information_group_URL_add_edit_URL' => 'Group already contains information item with the name in URL coinciding with the URL of subgroup to be added/deleted!',
	'changeActive_success' => 'Status changed successfully!',
	'changeIndexation_success' => 'Information group modified successfully.',
	'apply_success' => 'Information modified successfully.',
	'copy_success' => 'Information group copied successfully!',
	'move_success' => 'Information groups have been transferred',

	'show_information_propertys_groups_title' => 'Additional properties of groups of information system "%s"',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'tab_export' => 'Export/Import',
	'guid' => '<acronym title="Group identifier, e.g. ID00029527">GUID</acronym>',
	'tab_seo_templates' => 'SEO templates',
	'seo_group_header' => 'Group templates',
	'seo_item_header' => 'Item templates',
	'seo_group_title_template' => 'TITLE template',
	'seo_group_description_template' => 'DESCRIPTION template',
	'seo_group_keywords_template' => 'KEYWORDS template',
	'seo_item_title_template' => 'TITLE template',
	'seo_item_description_template' => 'DESCRIPTION template',
	'seo_item_keywords_template' => 'KEYWORDS template',
	'markDeleted' => 'Delete group',
);

==> HostCMS.Free_7.0.tar.gz: modules/informationsystem/group/i18n/en.php <==
<?php

return array(
	'model_name' => 'Information groups',
	'information_system_top_menu_groups' => 'Information group',
	'show_information_groups_link1' => 'Add',
	'show_information_groups_link4' => 'Properties',
	'information_groups_add_form_title' => 'Add information group',
	'information_groups_edit_form_title' => 'Edit information group',
	'tab_1' => 'Description',
	'tab_2' => 'SEO',
	'tab_3' => 'Additional properties',

	'id' => 'ID',
	'informationsystem_id' => 'Informationsystem id',
	'name' => 'Name of information group',
	'description' => 'Description of information group',
	'exec_typograph_description' => 'Use prepress service',
	'use_trailing_punctuation' => '<acronym title="Optical text alignment function moves punctuation characters beyond the typing borders">Optical alignment</acronym>',
	'parent_id' => 'Parent group',
	'sorting' => 'Sort',
	'path' => 'Path',
	'indexing' => 'Index',
	'active' => 'Active',
	'siteuser_id' => 'Client',
	'siteuser_group_id' => 'Customer Group',
	'information_parent' => 'Like parent',

	'image_large' => 'Picture',
	'image_small' => 'Small picture',

	'seo_title' => 'Title',
	'seo_description' => 'Description',
	'seo_keywords' => 'Keywords',

	'edit_success' => 'Information system added successfully.',
	'edit_error' => 'Information group has not been added!',
	'markDeleted_success' => 'Information group deleted successfully.',
	'markDeleted_error' => 'Information group has not been deleted!',

	'error_URL_information_group' => 'Group already contains information subgroup with this URL!',
	'error_information_group_URL_add_edit_URL' => 'Group already contains information item with the name in URL coinciding with the URL of subgroup to be added/deleted!',
	'changeActive_success' => 'Status changed successfully!',
	'changeIndexation_success' => 'Information group modified successfully.',
	'apply_success' => 'Information modified successfully.',
	'copy_success' => 'Information group copied successfully!',
	'move_success' => 'Information groups have been transferred',

	'show_information_propertys_groups_title' => 'Additional properties of groups of information system "%s"',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'tab_export' => 'Export/Import',
	'guid' => '<acronym title="Group identifier, e.g. ID00029527">GUID</acronym>',
	'tab_seo_templates' => 'SEO templates',
	'seo_group_header' => 'Group templates',
	'seo_item_header' => 'Item templates',
	'seo_group_title_template' => 'TITLE template',
	'seo_group_description_template' => 'DESCRIPTION template',
	'seo_group_keywords_template' => 'KEYWORDS template',
	'seo_item_title_template' => 'TITLE template',
	'seo_item_description_template' => 'DESCRIPTION template',
	'seo_item_keywords_template' => 'KEYWORDS template',
	'markDeleted' => 'Delete group',
	'shortcut_success' => "Group shortcut added successfully",
	'seo_group_h1_template' => 'H1 Template',
	'seo_item_h1_template' => 'H1 Template',
);
